@@ -2,11 +2,16 @@
 
 data(ardieres)
 plot(ardieres, ylab = expression(paste("Flood Discharge  ",m^3/s, sep="")),
-     xlab = "Years", main = "River Ardires at Beaujeu")
-cat("The threshold was initially to low. Select another threshold more suitable
-for the GP assumtion...")
-flows <- ardieres[,"flows"]
-date <- ardieres[,"date"]
+     xlab = "Years", main = "River Ardieres at Beaujeu", type = "l", col = "blue")
+cat("First, we have to identify clusters of extreme events...\n")
+readline("Press ENTER to continue")
+cat("Two extremes events are considered independent if they do not lie with a 10 days temporal window...\n")
+clust(ardieres, 4, 10 / 365, plot = TRUE)
+cat("Select only maxima within clusters.\n")
+readline("Press ENTER to continue")
+ardieres <- clust(ardieres, 4, 10 / 365, clust.max = TRUE)
+flows <- ardieres[, "obs"]
+date <- ardieres[, "time"]
 par(mfrow=c(1,2),ask = TRUE)
 diplot(ardieres)
 mrlplot(flows)
@@ -16,12 +21,12 @@ diplot(ardieres)
 abline(v = 6)
 mrlplot(flows)
 abline(v = 6)
-tcplot(flows, tlim =c(4,12))
-cat("But, is the GP distribution suited to model our data")
+tcplot(flows, u.range =c(4,12))
+cat("But, is the GP distribution suited to model our data ?")
 par(mfrow=c(1,1))
 lmomplot(flows, identify = FALSE)
 cat("Now, fit the GP distribution to exceedances above this threshold.")
-fitted <- fitgpd(flows, 6, 'mle',corr = TRUE)
+fitted <- fitgpd(flows, 6, 'mle', corr = TRUE)
 readline("Press ENTER to continue")
 cat("If, we want PWM estimates - unbiased one.")
 fitgpd(flows, 6, 'pwmu')
@@ -36,7 +41,7 @@ gpd.fiscale(fitted)
 readline("Press ENTER to continue")
 gpd.fishape(fitted)
 readline("Press ENTER to continue")
-par(mfrow=c(1,1),ask=TRUE)
+par(mfrow=c(1,1), ask = TRUE)
 cat("The same can also be obtained for return levels...")
 mu <-  fitted$nhigh / diff(range(date))
 rp2prob(10, 2)
